#

##

##

    	membership

    	objectives

    	possibilities

    		[ ] governance pool approval necessary for adding
    			an address to the network.

    			[ ] biometrics:
    					could need to submit verification in order
    					to join the network.

    					{
    						id:
    						video:
    					}

    					This might require a membership approval pool,
    					that is voted in to approve new members.